@@ -50,6 +50,9 @@ class DCTJPEG(_jpeg.JPEG):
         >>> jpeg = jpeglib,read_dct("input.jpeg")
         >>> jpeg.Y # jpeg.read_dct() called internally
         """
+        # no content
+        if self.content is None:
+            return None,(None,None),None
         # write content into temporary file
         tmp = tempfile.NamedTemporaryFile(suffix='.jpeg')
         tmp.write(self.content)
@@ -104,36 +107,40 @@ class DCTJPEG(_jpeg.JPEG):
         >>> jpeg = jpeglib.read_spatial("input.jpeg")
         >>> jpeg.write_spatial("output.jpeg", quality=92)
         """
-        # write content into temporary file
         tmp = tempfile.NamedTemporaryFile(suffix='jpeg')
-        tmp.write(self.content)
-        tmp.flush()
-        # parameters
+        if self.content is not None:
+            # write content into temporary file
+            tmp.write(self.content)
+            tmp.flush()
+        # path
         dstfile = path if path is not None else self.path
+        if dstfile is None:
+            raise IOError('no destination file specified')
         # convert dct
         def process_component(comp):
+            if comp is None:
+                return None
             comp = comp.reshape((*comp.shape[:-2],64))
             return np.ctypeslib.as_ctypes(comp.astype(np.int16))
         qt = process_component(self.qt)
         Y = process_component(self.Y)
-        if self.has_chrominance:
-            Cb = process_component(self.Cb)
-            Cr = process_component(self.Cr)
-        else: Cb,Cr = None,None
-        # convert qt
+        Cb = process_component(self.Cb)
+        Cr = process_component(self.Cr)
+        # quality and quantization table
         assert(quality in set(range(-1,101)))
         if quality != -1:
             qt = None
+            
         # call
         CJpegLib.write_jpeg_dct(
-            srcfile         = tmp.name,
+            srcfile         = tmp.name if self.content is not None else None,
             dstfile         = dstfile,
             Y               = Y,
             Cb              = Cb,
             Cr              = Cr,
             image_dims      = self.c_image_dims(),
             block_dims      = self.c_block_dims(),
-            in_color_space  = self.jpeg_color_space.name,
+            in_color_space  = self.jpeg_color_space.index,
             in_components   = self.num_components,
             qt              = qt,
             quality         = quality,
@@ -245,16 +252,23 @@ class DCTJPEGio(DCTJPEG):
     def __post_init__(self):
         self._jpeg_to_jpegio()
     def _jpeg_to_jpegio(self):
-        # collect dct
-        self._coef_arrays = [
-            self._convert_dct_jpegio(self.Y),
-            self._convert_dct_jpegio(self.Cb),
-            self._convert_dct_jpegio(self.Cr)
-        ]
-        self._quant_tables = [
-            self.get_component_qt(0).astype(np.int32),
-            self.get_component_qt(1).astype(np.int32)
-        ]
+        # colored image
+        if self.has_chrominance:
+            self._coef_arrays = [
+                self._convert_dct_jpegio(self.Y),
+                self._convert_dct_jpegio(self.Cb),
+                self._convert_dct_jpegio(self.Cr)
+            ]
+            self._quant_tables = [
+                self.get_component_qt(0).astype(np.int32),
+                self.get_component_qt(1).astype(np.int32)
+            ]
+        # grayscale
+        else:
+            self._coef_arrays = [self._convert_dct_jpegio(self.Y)]
+            self._quant_tables = [self.get_component_qt(0).astype(np.int32)]
+
+            
     def _jpegio_to_jpeg(self):
         self.Y = self._convert_jpegio_dct(self.coef_arrays[0])
         if self.has_chrominance:
@@ -268,7 +282,7 @@ class DCTJPEGio(DCTJPEG):
             self.quant_tbl_no = np.array([0,1,1])
         else:
             self.qt = np.array([
-                self.uant_tables[0]
+                self.quant_tables[0]
             ], dtype=np.uint16)
             self.quant_tbl_no = np.array([0])
     
