@@ -85,10 +85,21 @@ class SpatialJPEG(JPEG):
         
         >>> jpeg = jpeglib.read_spatial("input.jpeg")
         >>> jpeg.write_spatial("output.jpeg", qt=75)
+
+        To create a grayscale JPEG (only with luminance channel) using libjpeg color conversions
+
+        >>> x = np.random.randint(0,255,(16,16,3),dtype=np.uint8)
+        >>> im = jpeglib.from_spatial(x)
+        >>> im.jpeg_color_space = jpeglib.Colorspace('JCS_GRAYSCALE')
+        >>> im.write_spatial("hello.jpeg")
         """
         # colorspace
-        if self.color_space is None:
-            self.color_space = self.jpeg_color_space
+        if self.jpeg_color_space is not None:
+            jpeg_color_space = self.jpeg_color_space
+        else:
+            jpeg_color_space = self.color_space
+        num_components = (ctypes.c_int*2)(self.color_space.channels, jpeg_color_space.channels)
+        jpeg_color_space = (ctypes.c_int*2)(self.color_space.index, jpeg_color_space.index)
         # path
         dstfile = path if path is not None else self.path
         if dstfile is None:
@@ -120,8 +131,8 @@ class SpatialJPEG(JPEG):
             dstfile             = dstfile,
             spatial             = spatial,
             image_dims          = self.c_image_dims(),
-            in_color_space      = self.color_space.index,
-            in_components       = self.color_space.channels,
+            jpeg_color_space    = jpeg_color_space,
+            num_components      = num_components,
             dct_method          = dct_method,
             samp_factor         = self.c_samp_factor(),
             qt                  = qt,
